import { useState } from 'react';
import { Button, Container, Row, Col } from 'react-bootstrap';
import ChatMessage from './ChatMessage';

const testMessages = [
    {
        id: 1,
        role: 'user',
        content: '你好，可以帮我介绍一下React Hooks吗？',
        created_at: '2024-01-01 10:00:00',
    },
    {
        id: 2,
        role: 'assistant',
        content: `# React Hooks 详解

React Hooks 是 React 16.8 版本引入的新特性，它允许你在**不编写 class 组件**的情况下使用 state 以及其他的 React 特性。

## 主要的 Hooks

### 1. useState
\`useState\` 是最常用的 Hook，用于在函数组件中添加状态：

\`\`\`javascript
import { useState } from 'react';

function Counter() {
  const [count, setCount] = useState(0);
  
  return (
    <div>
      <p>你点击了 {count} 次</p>
      <button onClick={() => setCount(count + 1)}>
        点击我
      </button>
    </div>
  );
}
\`\`\`

### 2. useEffect
\`useEffect\` 用于处理副作用，如数据获取、订阅或手动更改 DOM：

\`\`\`javascript
import { useState, useEffect } from 'react';

function Example() {
  const [count, setCount] = useState(0);

  // 相当于 componentDidMount 和 componentDidUpdate:
  useEffect(() => {
    document.title = \`你点击了 \${count} 次\`;
  });

  return (
    <div>
      <p>你点击了 {count} 次</p>
      <button onClick={() => setCount(count + 1)}>
        点击我
      </button>
    </div>
  );
}
\`\`\`

## 优势

| 特性 | Class 组件 | Hooks |
|------|-----------|-------|
| 状态管理 | this.state | useState |
| 生命周期 | 复杂的生命周期方法 | useEffect |
| 逻辑复用 | 高阶组件/渲染属性 | 自定义Hooks |
| 代码量 | 较多 | 较少 |

## 注意事项

> **重要**: 只在最顶层使用 Hook，不要在循环、条件或嵌套函数中调用 Hook。

### 自定义 Hook
你可以创建自定义 Hook 来复用状态逻辑：

\`\`\`javascript
function useCounter(initialValue = 0) {
  const [count, setCount] = useState(initialValue);
  
  const increment = () => setCount(count + 1);
  const decrement = () => setCount(count - 1);
  const reset = () => setCount(initialValue);
  
  return { count, increment, decrement, reset };
}
\`\`\`

希望这个介绍对你有帮助！如果有任何问题，随时问我。`,
        created_at: '2024-01-01 10:01:00',
    },
    {
        id: 3,
        role: 'user',
        content: '这个示例很清楚！能再给我一个复杂的代码示例吗？',
        created_at: '2024-01-01 10:02:00',
    },
    {
        id: 4,
        role: 'assistant',
        content: `# 复杂的 React Hooks 示例

下面是一个更复杂的示例，展示了多个 Hooks 的组合使用：

## 用户列表组件

\`\`\`javascript
import React, { useState, useEffect, useCallback, useMemo } from 'react';

function UserList() {
  const [users, setUsers] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [searchTerm, setSearchTerm] = useState('');
  const [sortBy, setSortBy] = useState('name');

  // 获取用户数据
  const fetchUsers = useCallback(async () => {
    try {
      setLoading(true);
      setError(null);
      const response = await fetch('/api/users');
      if (!response.ok) {
        throw new Error('Failed to fetch users');
      }
      const userData = await response.json();
      setUsers(userData);
    } catch (err) {
      setError(err.message);
    } finally {
      setLoading(false);
    }
  }, []);

  // 组件挂载时获取数据
  useEffect(() => {
    fetchUsers();
  }, [fetchUsers]);

  // 过滤和排序用户
  const filteredAndSortedUsers = useMemo(() => {
    let filtered = users.filter(user =>
      user.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
      user.email.toLowerCase().includes(searchTerm.toLowerCase())
    );

    return filtered.sort((a, b) => {
      if (sortBy === 'name') {
        return a.name.localeCompare(b.name);
      } else if (sortBy === 'email') {
        return a.email.localeCompare(b.email);
      } else if (sortBy === 'joinDate') {
        return new Date(b.joinDate) - new Date(a.joinDate);
      }
      return 0;
    });
  }, [users, searchTerm, sortBy]);

  // 删除用户
  const deleteUser = useCallback(async (userId) => {
    if (!window.confirm('确定要删除这个用户吗？')) return;
    
    try {
      await fetch(\`/api/users/\${userId}\`, { method: 'DELETE' });
      setUsers(prev => prev.filter(user => user.id !== userId));
    } catch (err) {
      alert('删除失败：' + err.message);
    }
  }, []);

  if (loading) return <div className="spinner">加载中...</div>;
  if (error) return <div className="error">错误: {error}</div>;

  return (
    <div className="user-list">
      <h2>用户列表 ({filteredAndSortedUsers.length})</h2>
      
      {/* 搜索和排序控件 */}
      <div className="controls">
        <input
          type="text"
          placeholder="搜索用户..."
          value={searchTerm}
          onChange={(e) => setSearchTerm(e.target.value)}
          className="search-input"
        />
        <select
          value={sortBy}
          onChange={(e) => setSortBy(e.target.value)}
          className="sort-select"
        >
          <option value="name">按姓名排序</option>
          <option value="email">按邮箱排序</option>
          <option value="joinDate">按加入日期排序</option>
        </select>
      </div>

      {/* 用户列表 */}
      <div className="users">
        {filteredAndSortedUsers.map(user => (
          <UserCard
            key={user.id}
            user={user}
            onDelete={() => deleteUser(user.id)}
          />
        ))}
      </div>
    </div>
  );
}

// 用户卡片组件
const UserCard = React.memo(({ user, onDelete }) => {
  return (
    <div className="user-card">
      <img src={user.avatar} alt={user.name} className="avatar" />
      <div className="user-info">
        <h3>{user.name}</h3>
        <p>{user.email}</p>
        <small>加入时间: {new Date(user.joinDate).toLocaleDateString()}</small>
      </div>
      <button onClick={onDelete} className="delete-btn">
        删除
      </button>
    </div>
  );
});

export default UserList;
\`\`\`

## 关键特性解析

### 🔥 性能优化
- \`useCallback\`: 缓存函数，避免不必要的重新创建
- \`useMemo\`: 缓存计算结果，避免重复计算
- \`React.memo\`: 防止子组件不必要的重渲染

### 📊 状态管理
- 多个 \`useState\` 管理不同的状态
- 复杂的状态更新逻辑

### 🎯 副作用处理
- \`useEffect\` 处理数据获取
- 清理函数处理内存泄漏

这个示例展示了在实际项目中如何组合使用多个 Hooks 来构建功能完整的组件！`,
        created_at: '2024-01-01 10:03:00',
    },
];

export default function ChatTest() {
    const [messages, setMessages] = useState(testMessages);
    const [streamingMessageId, setStreamingMessageId] = useState(null);

    const simulateStreaming = () => {
        const newMessage = {
            id: messages.length + 1,
            role: 'assistant',
            content: `# 实时流式渲染演示

这是一个**实时流式渲染**的演示。文本会逐字显示，模拟真实的AI对话体验。

## 特性展示

### 1. 打字机效果
- 文字逐个显示
- 可以跳过动画
- 流畅的视觉体验

### 2. Markdown 支持
支持完整的Markdown语法：

\`\`\`javascript
// 代码高亮示例
function hello() {
  console.log("Hello, World!");
  return "streaming";
}
\`\`\`

### 3. 表格支持

| 功能 | 状态 | 说明 |
|------|------|------|
| 打字机效果 | ✅ | 完成 |
| 代码高亮 | ✅ | 完成 |
| 表格渲染 | ✅ | 完成 |

> 这是一个引用块的示例，用来展示特殊内容。

### 4. 列表支持

1. 有序列表项1
2. 有序列表项2
3. 有序列表项3

- 无序列表项A
- 无序列表项B
- 无序列表项C

**粗体文本** 和 *斜体文本* 也完全支持！

[链接示例](https://react.dev) 可以正常工作。

---

这就是流式渲染的完整演示！`,
            created_at: new Date().toISOString(),
        };

        setMessages((prev) => [...prev, newMessage]);
        setStreamingMessageId(newMessage.id);

        // 模拟流式完成后清除streaming状态
        setTimeout(() => {
            setStreamingMessageId(null);
        }, newMessage.content.length * 20 + 2000);
    };

    return (
        <Container fluid className='mt-4'>
            <Row>
                <Col md={8} className='mx-auto'>
                    <div className='d-flex justify-content-between align-items-center mb-4'>
                        <h2>聊天组件测试</h2>
                        <Button onClick={simulateStreaming} variant='primary'>
                            开始流式演示
                        </Button>
                    </div>

                    <div
                        className='chat-test-container'
                        style={{
                            background: 'white',
                            borderRadius: '12px',
                            padding: '20px',
                            boxShadow: '0 2px 10px rgba(0,0,0,0.1)',
                            maxHeight: '70vh',
                            overflowY: 'auto',
                        }}
                    >
                        {messages.map((message) => (
                            <ChatMessage
                                key={message.id}
                                message={message}
                                isStreaming={message.id === streamingMessageId}
                            />
                        ))}
                    </div>
                </Col>
            </Row>
        </Container>
    );
}
