import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { useState } from 'react';
import { Button, Modal, Table } from 'react-bootstrap';
import { useSelector, useDispatch } from 'react-redux';
import { Link } from 'react-router-dom';
import { getCategoryClassName } from '../lib/utils.jsx';

export default function DiscoveryList() {
    const dispatch = useDispatch();
    const { sessions, error, status } = useSelector((state) => state.discovery);
    const [showSessionResultModal, setShowSessionResultModal] = useState(false);
    const [selectedSession, setSelectedSession] = useState(null);


    // 如果加载失败，显示错误信息
    if (status === 'failed') {
        return <div className='alert alert-danger'>{error || 'Failed to load creators. Please try again later.'}</div>;
    }

    const handleViewSession = (session) => {
        setSelectedSession(session);
        setShowSessionResultModal(true);
    }

    return (
        <div className='discovery-list'>
            <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden border-1'>
                <thead>
                    <tr>
                        <th className='text-center'>Sessions</th>
                        <th className='text-center'>#Creator</th>
                        <th className='text-center'>#Shoppable Creators</th>
                        <th className='text-center'>Avg.Followers</th>
                        <th className='text-center'>Avg.GMV</th>
                        <th className='text-center'>Avg.Video Views</th>
                        <th className='text-center'>Date</th>
                        <th className='text-center'>View Details</th>
                    </tr>
                </thead>
                <tbody>
                    {sessions?.length > 0 ? (
                        sessions.map((session) => (
                            <tr key={session.id}>
                                <td className='text-center'>{session.session_number}</td>
                                <td className='text-center'>{session.creator_count}</td>
                                <td className='text-center'>{session.shoppable_creators}</td>
                                <td className='text-center'>{session.avg_followers}</td>
                                <td className='text-center'>{session.avg_gmv}</td>
                                <td className='text-center'>{session.avg_video_views}</td>
                                <td className='text-center'>{session.date_created}</td>
                                <td className='text-center'>
                                    <Button variant='primary' onClick={() => handleViewSession(session)}>View</Button>
                                </td>
                            </tr>
                        ))
                    ) : (
                        <tr>
                            <td colSpan='7' className='text-center'>
                                No session found
                            </td>
                        </tr>
                    )}
                </tbody>
            </Table>
            <SeesionResultModal session={selectedSession} show={showSessionResultModal} onHide={() => setShowSessionResultModal(false)} />
        </div>
    );
}

function SeesionResultModal({ session, show, onHide }) {
    if (!show) return null;
    const { creators } = session || {};
    return (
        <Modal show={show} onHide={onHide} size={creators.length > 0 ? 'xl' : ''}>
            <Modal.Header closeButton>
                <Modal.Title>Session Result</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                {
                    creators.length > 0 ? (
                        <Table responsive hover className='creator-database-table bg-white shadow-xs rounded overflow-hidden'>
                            <thead className='sticky-header'>
                        <tr>
                            <th className='creator' style={{ width: '180px' }}>
                                Creator
                            </th>
                            <th
                                className='category text-center'
                                style={{ width: '180px' }}
                            >
                                Category
                            </th>
                            <th className='e-commerce-level text-center'>
                                E-commerce Level
                            </th>
                            <th className='exposure-level text-center'>
                                Exposure Level
                            </th>
                            <th className='followers text-center'>
                                Followers
                            </th>
                            <th className='gmv text-center'>
                                GMV
                            </th>
                            <th className='views text-center'>
                                Avg. Video Views
                            </th>
                            <th className='e-commerce text-center'>E-commerce</th>
                            <th className='profile text-center'>Profile</th>
                        </tr>
                    </thead>
                    <tbody>
                        {session.creators.length <= 0 ? (
                            <tr>
                                <td colSpan='10' className='text-center py-4'>
                                    No creators found matching your filters.
                                </td>
                            </tr>
                        ) : (
                            session.creators.map((creator) => (
                                <tr
                                    key={creator.id}
                                >
                                    <td className='creator-cell'>
                                        <Link to={`/creator/${creator.id}`} className='d-flex align-items-center'>
                                            <div className='creator-avatar'>
                                                <img src={creator.avatar} alt={creator.name} />
                                            </div>
                                            <div className='creator-name'>
                                                {creator.name}
                                            </div>
                                        </Link>
                                    </td>
                                    <td className='text-center'>
                                        <span className={`category-pill ${getCategoryClassName(creator.category)}`}>
                                            {creator.category || '--'}
                                        </span>
                                    </td>
                                    <td className='text-center'>
                                        <span className='level-badge ecommerce-level'>{creator.ecommerce_level}</span>
                                    </td>
                                    <td className='text-center'>
                                        <span
                                            className='level-badge exposure-level'
                                            data-level={creator.exposure_level}
                                        >
                                            {creator.exposure_level}
                                        </span>
                                    </td>
                                    <td className='text-nowrap text-center'>{creator.followers}</td>
                                    <td className='text-center'>
                                        <div>{creator.gmv}</div>
                                        <div className='small text-muted'>Items Sold: {creator.soldPercentage}</div>
                                    </td>
                                    <td className='text-nowrap text-center'>{creator.avg_video_views}</td>
                                    <td className='text-center'>
                                        {creator.has_ecommerce ? <div className='colored-dot bg-primary mx-auto'></div> : null}
                                    </td>
                                    <td className='text-center'>
                                        {creator.hasTiktok && (
                                            <div className='social-icon tiktok-icon mx-auto'>
                                                <FontAwesomeIcon icon='fa-brands fa-tiktok' />
                                            </div>
                                        )}
                                    </td>
                                </tr>
                            ))
                        )}
                            </tbody>
                        </Table>
                    ) : (
                        <div className='text-center py-4'>No creators found in this session.</div>
                    )
                }
            </Modal.Body>
        </Modal>
    )
}