import React, { useState, useEffect } from 'react';
import { Link, useLocation } from 'react-router-dom';
import { Nav, Accordion, Button } from 'react-bootstrap';
import {
    Settings,
    ChevronDown,
    Blocks,
    SquareActivity,
    LayoutDashboard,
    Mail,
    UserSearch,
    Heart,
    Send,
    FileText,
    LogOut,
} from 'lucide-react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import logo from '@/assets/logo.png';
import '@/styles/sidebar.scss';
import { useDispatch } from 'react-redux';

// Organized menu items
const menuItems = [
    {
        id: 'creator-discovery',
        title: 'Creator Discovery',
        path: '/creator-discovery',
        icon: <UserSearch />,
        hasSubmenu: false,
    },
    {
        id: 'creator-database',
        title: 'Creator Database',
        path: '/creator-database',
        icon: <Blocks />,
        hasSubmenu: true,
        submenuItems: [
            {
                id: 'tiktok',
                title: 'TikTok',
                path: '/creator-database/tiktok',
                icon: <FontAwesomeIcon icon='fa-brands fa-tiktok' />,
            },
            {
                id: 'instagram',
                title: 'Instagram',
                path: '/creator-database/instagram',
                icon: <FontAwesomeIcon icon='fa-brands fa-instagram' />,
            },
            {
                id: 'youtube',
                title: 'YouTube',
                path: '/creator-database/youtube',
                icon: <FontAwesomeIcon icon='fa-brands fa-youtube' />,
            },
        ],
    },
    {
        id: 'private-creators',
        title: 'Private Creators',
        path: '/private-creators',
        icon: <Heart />,
        hasSubmenu: true,
        submenuItems: [
            {
                id: 'tiktok',
                title: 'TikTok',
                path: '/private-creators/tiktok',
                icon: <FontAwesomeIcon icon='fa-brands fa-tiktok' />,
            },
            {
                id: 'instagram',
                title: 'Instagram',
                path: '/private-creators/instagram',
                icon: <FontAwesomeIcon icon='fa-brands fa-instagram' />,
            },
            {
                id: 'youtube',
                title: 'YouTube',
                path: '/private-creators/youtube',
                icon: <FontAwesomeIcon icon='fa-brands fa-youtube' />,
            },
        ],
    },
    {
        id: 'deep-analysis',
        title: 'Deep Analysis',
        path: '/deep-analysis',
        icon: <SquareActivity />,
        hasSubmenu: false,
    },
    {
        id: 'brands',
        title: 'Brands',
        path: '/brands',
        icon: <LayoutDashboard />,
        hasSubmenu: false,
    },
    {
        id: 'creator-inbox',
        title: 'Creator Inbox',
        path: '/creator-inbox',
        icon: <Mail />,
        hasSubmenu: true,
        submenuItems: [
            {
                id: 'inbox',
                title: 'Inbox',
                path: '/creator-inbox',
                icon: <Send />,
            },
            {
                id: 'templates',
                title: 'Templates',
                path: '/inbox-templates',
                icon: <FileText />,
            },
        ],
    },
    {
        id: 'settings',
        title: 'Settings',
        path: '/settings',
        icon: <Settings />,
        hasSubmenu: false,
    },
];

export default function Sidebar() {
    const location = useLocation();
    const [expanded, setExpanded] = useState({});
    const [collapsed, setCollapsed] = useState(false);

    // 监听窗口大小变化
    useEffect(() => {
        const handleResize = () => {
            setCollapsed(window.innerWidth < 768);
        };

        // 初始化
        handleResize();

        window.addEventListener('resize', handleResize);
        return () => window.removeEventListener('resize', handleResize);
    }, []);

    // 检查路径是否匹配当前路由
    const isActive = (path) => {
        return location.pathname === path || location.pathname.startsWith(`${path}/`);
    };

    // 检查是否有子项是激活状态
    const hasActiveChild = (item) => {
        if (!item.submenuItems) return false;
        return item.submenuItems.some((subItem) => isActive(subItem.path));
    };

    // 处理手风琴项的展开/折叠
    const handleAccordionToggle = (id) => {
        setExpanded((prev) => ({
            ...prev,
            [id]: !prev[id],
        }));
    };

    return (
        <div className={`sidebar ${collapsed ? 'sidebar-collapsed' : ''}`}>
            <Link to='/' className='sidebar-header p-3 d-flex align-items-center'>
                <img src={logo} alt='OOIN Logo' width={48} height={48} className='me-2' />
                {!collapsed && (
                    <div>
                        <div className='text-black fw-bold'>OOIN Media</div>
                        <div className='small text-muted'>Creator Center</div>
                    </div>
                )}
            </Link>

            <Nav className='flex-column sidebar-nav'>
                {menuItems.map((item) => {
                    if (item.hasSubmenu) {
                        const isItemActive = isActive(item.path) || hasActiveChild(item);
                        const isOpen = expanded[item.id] || isItemActive;

                        return (
                            <Accordion key={item.id} className='sidebar-accordion' activeKey={isOpen ? item.id : null}>
                                <Accordion.Item eventKey={item.id} className='border-0 bg-transparent'>
                                    <Accordion.Header
                                        onClick={() => handleAccordionToggle(item.id)}
                                        className={`${isItemActive ? 'active' : ''} ${
                                            collapsed ? 'collapsed-header' : ''
                                        }`}
                                    >
                                        <div
                                            className={`d-flex align-items-center ${
                                                collapsed ? 'justify-content-center w-100' : ''
                                            }`}
                                        >
                                            <span className='sidebar-icon me-2'>{item.icon}</span>
                                            {!collapsed && item.title}
                                        </div>
                                    </Accordion.Header>
                                    {!collapsed && (
                                        <Accordion.Body className='p-0'>
                                            <Nav className='flex-column sidebar-submenu'>
                                                {item.submenuItems &&
                                                    item.submenuItems.map((subItem) => (
                                                        <Nav.Item key={`${item.id}-${subItem.id}`}>
                                                            <Nav.Link
                                                                as={Link}
                                                                to={subItem.path}
                                                                className={isActive(subItem.path) ? 'active' : ''}
                                                            >
                                                                <span className='sidebar-icon me-2'>
                                                                    {subItem.icon}
                                                                </span>
                                                                {!collapsed && subItem.title}
                                                            </Nav.Link>
                                                        </Nav.Item>
                                                    ))}
                                            </Nav>
                                        </Accordion.Body>
                                    )}
                                </Accordion.Item>
                            </Accordion>
                        );
                    } else {
                        return (
                            <Nav.Item key={item.id}>
                                <Nav.Link as={Link} to={item.path} className={isActive(item.path) ? 'active' : ''}>
                                    <span className='sidebar-icon me-2'>{item.icon}</span>
                                    {!collapsed && item.title}
                                </Nav.Link>
                            </Nav.Item>
                        );
                    }
                })}
            </Nav>
            <div className='sidebar-footer'>
                <Button variant='outline-danger'>
                    <LogOut />
                </Button>
            </div>
        </div>
    );
}
