import React, { useState, useEffect, useRef } from 'react';
import '../styles/RangeSlider.scss';
import debounce from 'lodash/debounce';

export default function RangeSlider({ value, onChange, discreteValues }) {
    // 预定义的离散值点
    // const discreteValues = [0, 100, 1000, 10000, 100000, 250000, 500000];
    const marks = ['0', '100', '1k', '10k', '100k', '250k', '500k+'];

    // 使用索引位置作为滑块的实际值，以实现等分
    const getIndexForValue = (val) => {
        for (let i = 0; i < discreteValues.length; i++) {
            if (val <= discreteValues[i]) {
                return i;
            }
        }
        return discreteValues.length - 1;
    };

    // 找到最接近的离散值索引
    const findClosestDiscreteIndex = (value) => {
        let closestIndex = 0;
        let minDiff = Math.abs(discreteValues[0] - value);

        for (let i = 1; i < discreteValues.length; i++) {
            const diff = Math.abs(discreteValues[i] - value);
            if (diff < minDiff) {
                minDiff = diff;
                closestIndex = i;
            }
        }

        return closestIndex;
    };

    // 初始化使用给定值的索引位置
    const initialMinIndex = findClosestDiscreteIndex(value[0]);
    const initialMaxIndex = findClosestDiscreteIndex(value[1]);

    const [minValIndex, setMinValIndex] = useState(initialMinIndex);
    const [maxValIndex, setMaxValIndex] = useState(initialMaxIndex);
    const minValIndexRef = useRef(initialMinIndex);
    const maxValIndexRef = useRef(initialMaxIndex);
    const range = useRef(null);

    // 将索引转换为百分比位置
    const getPercent = (index) => {
        return Math.round((index / (discreteValues.length - 1)) * 100);
    };

    const debouncedOnChange = useRef(
        debounce((minIndex, maxIndex) => {
            onChange([discreteValues[minIndex], discreteValues[maxIndex]]);
        }, 300)
    ).current;

    // 更新内部状态以匹配外部传入的值
    useEffect(() => {
        const newMinIndex = findClosestDiscreteIndex(value[0]);
        const newMaxIndex = findClosestDiscreteIndex(value[1]);

        setMinValIndex(newMinIndex);
        setMaxValIndex(newMaxIndex);
        minValIndexRef.current = newMinIndex;
        maxValIndexRef.current = newMaxIndex;
    }, [value]);

    // 设置上限和下限的宽度
    useEffect(() => {
        if (range.current) {
            const minPercent = getPercent(minValIndex);
            const maxPercent = getPercent(maxValIndexRef.current);

            range.current.style.left = `${minPercent}%`;
            range.current.style.width = `${maxPercent - minPercent}%`;
        }
    }, [minValIndex]);

    // 设置下限和区间的宽度
    useEffect(() => {
        if (range.current) {
            const minPercent = getPercent(minValIndexRef.current);
            const maxPercent = getPercent(maxValIndex);

            range.current.style.width = `${maxPercent - minPercent}%`;
        }
    }, [maxValIndex]);

    // 当值改变时通知父组件，但避免循环更新
    useEffect(() => {
        const minVal = discreteValues[minValIndex];
        const maxVal = discreteValues[maxValIndex];

        // 判断值是否与外部传入的值不同
        if (minVal !== value[0] || maxVal !== value[1]) {
            debouncedOnChange(minValIndex, maxValIndex);
        }
    }, [minValIndex, maxValIndex]);

    // 格式化显示的值（如1k, 10k, 100k等）
    const formatValue = (value) => {
        if (value >= 1000000) {
            return `${(value / 1000000).toFixed(1)}M`;
        }
        if (value >= 1000) {
            return `${(value / 1000).toFixed(0)}k`;
        }
        return value;
    };

    const handleSliderChange = (which, val) => {
        // 将输入值转换为索引（0-6）
        const index = Math.round(val);

        if (which === 'min') {
            // 确保最小值不超过最大值
            const newIndex = Math.min(index, maxValIndex - 1);
            setMinValIndex(newIndex);
            minValIndexRef.current = newIndex;
        } else {
            // 确保最大值不小于最小值
            const newIndex = Math.max(index, minValIndex + 1);
            setMaxValIndex(newIndex);
            maxValIndexRef.current = newIndex;
        }
    };

    const handleMouseUp = () => {
        onChange([discreteValues[minValIndex], discreteValues[maxValIndex]]);
    };

    return (
        <div className='range-slider slider-container'>
            <input
                type='range'
                min={0}
                max={discreteValues.length - 1}
                step={1}
                value={minValIndex}
                onChange={(e) => handleSliderChange('min', +e.target.value)}
                onMouseUp={handleMouseUp}
                onTouchEnd={handleMouseUp}
                className='thumb thumb--left'
                style={{ zIndex: minValIndex > discreteValues.length - 3 ? 5 : 4 }}
            />
            <input
                type='range'
                min={0}
                max={discreteValues.length - 1}
                step={1}
                value={maxValIndex}
                onChange={(e) => handleSliderChange('max', +e.target.value)}
                onMouseUp={handleMouseUp}
                onTouchEnd={handleMouseUp}
                className='thumb thumb--right'
            />

            <div className='slider'>
                <div className='slider__track'></div>
                <div ref={range} className='slider__range'></div>
                {/* 添加离散标记点 */}
                <div className='slider__steps'>
                    {discreteValues.map((_, index) => (
                        <div
                            key={index}
                            className={`slider__step ${index >= minValIndex && index <= maxValIndex ? 'active' : ''}`}
                            style={{ left: `${getPercent(index)}%` }}
                        />
                    ))}
                </div>
            </div>
            <div className='range-slider-marks'>
                {discreteValues.map((mark, index) => (
                    <span key={index}>{formatValue(mark)}</span>
                ))}
            </div>
            {/* 显示当前选中的值 */}
            {/* <div className='slider__values'>
                <div className='slider__value-left' style={{ left: `${getPercent(minValIndex)}%` }}>
                    {formatValue(discreteValues[minValIndex])}
                </div>
                <div className='slider__value-right' style={{ left: `${getPercent(maxValIndex)}%` }}>
                    {formatValue(discreteValues[maxValIndex])}
                </div>
            </div> */}
        </div>
    );
}
