import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import { Button } from 'react-bootstrap';
import { X } from 'lucide-react';
import './SlidePanel.scss';

/**
 * SlidePanel - A reusable offcanvas-like component
 * @param {Object} props
 * @param {boolean} props.show - Controls visibility of the panel
 * @param {function} props.onClose - Function to call when panel is closed
 * @param {string} props.placement - Side from which the panel appears (start, end, top, bottom)
 * @param {string} props.title - Title to display in the panel header
 * @param {ReactNode} props.children - Content to display in the panel body
 * @param {string} props.size - Size of the panel (sm, md, lg)
 * @param {boolean} props.backdrop - Whether to show backdrop
 * @param {boolean} props.closeButton - Whether to show close button in header
 */
const SlidePanel = ({
    show,
    onClose,
    placement = 'end',
    title,
    children,
    size = 'md',
    backdrop = true,
    closeButton = true,
}) => {
    const [isVisible, setIsVisible] = useState(false);

    // Handle animation timing
    useEffect(() => {
        if (show) {
            setIsVisible(true);
        } else {
            const timer = setTimeout(() => setIsVisible(false), 300);
            return () => clearTimeout(timer);
        }
    }, [show]);

    if (!isVisible && !show) {
        return null;
    }

    const handleBackdropClick = () => {
        if (backdrop && onClose) {
            onClose();
        }
    };

    return (
        <div className={`slide-panel-container ${show ? 'show' : ''}`}>
            {backdrop && <div className={`slide-panel-backdrop ${show ? 'show' : ''}`} onClick={handleBackdropClick} />}

            <div
                className={`slide-panel ${show ? 'show' : ''} slide-panel-${placement} slide-panel-${size}`}
                onClick={(e) => e.stopPropagation()}
            >
                <div className='slide-panel-header'>
                    {title && <div className='slide-panel-title'>{title}</div>}
                    {closeButton && (
                        <Button variant='link' className='slide-panel-close' onClick={onClose} aria-label='Close'>
                            <X size={20} />
                        </Button>
                    )}
                </div>
                <div className='slide-panel-body'>{children}</div>
            </div>
        </div>
    );
};

SlidePanel.propTypes = {
    show: PropTypes.bool.isRequired,
    onClose: PropTypes.func.isRequired,
    placement: PropTypes.oneOf(['start', 'end', 'top', 'bottom']),
    title: PropTypes.node,
    children: PropTypes.node,
    size: PropTypes.oneOf(['sm', 'md', 'lg']),
    backdrop: PropTypes.bool,
    closeButton: PropTypes.bool,
};

export default SlidePanel;
