import { format, isToday, parseISO } from 'date-fns';
import { BRAND_SOURCES } from './constant';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { Link } from 'react-router-dom';
import React from 'react';

/**
 * 格式化日期
 * @param {Date} date - 要格式化的日期对象
 * @param {string} format - 格式字符串 (默认为 'YYYY-MM-DD')
 * @returns {string} 格式化后的日期字符串
 */
export function formatDate(date, format = 'YYYY-MM-DD') {
    if (!date) return '';

    const d = new Date(date);
    const year = d.getFullYear();
    const month = String(d.getMonth() + 1).padStart(2, '0');
    const day = String(d.getDate()).padStart(2, '0');
    const hours = String(d.getHours()).padStart(2, '0');
    const minutes = String(d.getMinutes()).padStart(2, '0');
    const seconds = String(d.getSeconds()).padStart(2, '0');

    return format
        .replace('YYYY', year)
        .replace('MM', month)
        .replace('DD', day)
        .replace('HH', hours)
        .replace('mm', minutes)
        .replace('ss', seconds);
}

/**
 * 格式化数字
 * @param {number} number - 要格式化的数字
 * @param {number} decimals - 小数位数
 * @param {string} decimalPoint - 小数点符号
 * @param {string} thousandsSeparator - 千位分隔符
 * @returns {string} 格式化后的数字字符串
 */
export function formatNumber(number, decimals = 0, decimalPoint = '.', thousandsSeparator = ',') {
    if (isNaN(number)) return '0';

    const n = Number(number).toFixed(decimals);
    return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, thousandsSeparator);
}

export const getCategoryClassName = (category) => {
    const categoryMap = {
        'Phones & Electronics': 'phones',
        'Womenswear & Underwear': 'women',
        'Sports & Outdoor': 'sports',
        'Food & Beverage': 'food',
        Health: 'health',
        Kitchenware: 'kitchen',
    };

    return categoryMap[category] || '';
};

export const getBrandSourceName = (source) => {
    return BRAND_SOURCES.find((item) => item.value === source)?.name || source;
};

export const getTemplateMissionName = (mission) => {
    return TEMPLATE_MISSIONS.find((item) => item.value === mission)?.name || mission;
};

export const chatDateFormat = (date) => {
    const now = typeof date === 'string' ? parseISO(date) : date;
    if (isToday(now)) {
        return format(now, 'HH:mm');
    } else {
        return format(now, 'MMM do');
    }
};

export function determinProfileIcon(creator) {
    if (!creator) return '--';
    console.log(creator);
    if (creator.profile === 'tiktok') {
        return <Link to={creator.tiktok_link || ''} target='_blank'>
                <FontAwesomeIcon icon='fa-brands fa-tiktok' />
            </Link>;
    } else if (creator.profile === 'youtube') {
        return <Link to={creator.youtube_link || ''} target='_blank'>
                <FontAwesomeIcon icon='fa-brands fa-youtube' />
            </Link>;
    } else if (creator.profile === 'instagram') {
        return <Link to={creator.instagram_link || ''} target='_blank'>
                <FontAwesomeIcon icon='fa-brands fa-instagram' />
            </Link>;
    } else {
        return '--';
    }
}
