import React, { useEffect, useState } from 'react';
import SearchBar from '../components/SearchBar';
import { Alert, Button, Form, Modal } from 'react-bootstrap';
import { Folders, Hash, LinkIcon, Plus, Users, X } from 'lucide-react';
import { useDispatch, useSelector } from 'react-redux';
import { Link, useParams } from 'react-router-dom';
import CampaignList from '../components/CampaignList';
import ProductsList from '../components/ProductsList';
import {
    fetchBrandDetail,
    fetchBrandCampaigns,
    fetchBrandProducts,
    createCampaignThunk,
} from '../store/slices/brandsSlice';
import { setCurrentProduct } from '../store/slices/productSlice';
import SlidePanel from '../components/SlidePanel';
import ProductDetail, { CampaignsCollabCreators } from '../components/ProductDetail';
import { CAMPAIGN_SERVICES, CREATOR_CATEGORIES, CREATOR_LEVELS, CREATOR_TYPES, GMV_RANGES } from '../lib/constant';
import RangeSlider from '../components/RangeSlider';
import { setNotificationBarMessage } from '../store/slices/notificationBarSlice';

export default function BrandsDetail() {
    const { id } = useParams();
    const dispatch = useDispatch();
    const [activeTab, setActiveTab] = useState('campaigns');
    const { selectedBrand } = useSelector((state) => state.brands);
    const [showProductDetail, setShowProductDetail] = useState(false);
    const [showAddCampaignModal, setShowAddCampaignModal] = useState(false);
    const [showAddProductModal, setShowAddProductModal] = useState(false);

    useEffect(() => {
        if (id) {
            const fetchData = async () => {
                await dispatch(fetchBrandDetail(id)).unwrap();
                dispatch(fetchBrandCampaigns(id));
                dispatch(fetchBrandProducts(id));
            };

            fetchData();
        }
    }, [dispatch, id]);

    const handleShowProductDetail = (product) => {
        dispatch(setCurrentProduct(product));
        setShowProductDetail(true);
    };

    return (
        selectedBrand?.id && (
            <React.Fragment>
                <div className='function-bar'>
                    <SearchBar />
                    {activeTab === 'campaigns' && (
                        <Button onClick={() => setShowAddCampaignModal(true)}>
                            <Plus />
                            Add Campaign
                        </Button>
                    )}
                    {activeTab === 'products' && (
                        <Button onClick={() => setShowAddProductModal(true)}>
                            <Plus />
                            Add Product
                        </Button>
                    )}
                </div>
                <div className='breadcrumb'>
                    <Link to={'/brands'} className='breadcrumb-item'>
                        Brands
                    </Link>
                    <div className='breadcrumb-item'>{selectedBrand.name}</div>
                </div>
                <div className='brand-detail-info'>
                    <div className='brand-logo shadow-xs'>{selectedBrand.name.toUpperCase()}</div>
                    <div className='brand-info shadow-xs'>
                        <div className='brand-info-top'>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <Folders size={20} />
                                    商家分类
                                </div>
                                <div className='info-value'>{selectedBrand.category}</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <LinkIcon size={20} />
                                    Source
                                </div>
                                <div className='info-value'>{selectedBrand.source}</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <Hash size={20} />
                                    Collab.
                                </div>
                                <div className='info-value'>{selectedBrand.collab_count}</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-name'>
                                    <Users size={20} />
                                    Creators
                                </div>
                                <div className='info-value'>{selectedBrand.creators_count}</div>
                            </div>
                        </div>
                        <div className='brand-info-bottom'>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.creators_count}</div>
                                <div className='info-name'>Total Collab. Creators</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.total_gmv_achieved}</div>
                                <div className='info-name'>Total GMV Achieved</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.total_views_achieved}</div>
                                <div className='info-name'>Total Views Achieved</div>
                            </div>
                            <div className='info-item'>
                                <div className='info-value'>{selectedBrand.shop_overall_rating}</div>
                                <div className='info-name'>Shop Overall Rating</div>
                            </div>
                        </div>
                    </div>
                </div>
                <div className='brand-tab-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'campaigns' ? 'active' : ''}`}
                        onClick={() => setActiveTab('campaigns')}
                    >
                        Campaigns
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'products' ? 'active' : ''}`}
                        onClick={() => setActiveTab('products')}
                    >
                        Products
                    </div>
                </div>
                {activeTab === 'campaigns' && <CampaignList />}
                {activeTab === 'products' && (
                    <>
                        <ProductsList
                            products={selectedBrand?.products}
                            onShowProductDetail={handleShowProductDetail}
                            type='brand'
                        />
                        <SlidePanel
                            show={showProductDetail}
                            onClose={() => setShowProductDetail(false)}
                            title='Product Detail'
                            size='xxl'
                        >
                            <div className='product-details-panel'>
                                <ProductDetail />
                                <CampaignsCollabCreators />
                            </div>
                        </SlidePanel>
                    </>
                )}
                <AddCampaignModal
                    show={showAddCampaignModal}
                    onHide={() => setShowAddCampaignModal(false)}
                    brandId={id}
                />
                <AddProductModal show={showAddProductModal} onHide={() => setShowAddProductModal(false)} brandId={id} />
            </React.Fragment>
        )
    );
}

export function AddCampaignModal({ show, onHide, brandId }) {
    const dispatch = useDispatch();
    const [formData, setFormData] = useState({
        name: '',
        description: '',
        service: '',
        link_product: '',
        creator_type: '',
        creator_level: '',
        creator_count: 0,
        budget: [0, 200],
        creator_category: '',
        followers: [0, 100],
        gmv: '',
        views: [0, 100000],
    });
    const [validated, setValidated] = useState(false);
    const budgetDiscreteValues = [0, 200, 400, 600, 800, 1000, 3000];
    const followersDiscreteValues = [0, 100, 1000, 10000, 250000, 500000];
    const viewsDiscreteValues = [0, 50000, 100000, 300000, 500000, 1000000, 5000000];
    const [errors, setErrors] = useState({});
    const { status } = useSelector((state) => state.brands);

    const handleChange = (e) => {
        setFormData({ ...formData, [e.target.name]: e.target.value });
    };

    const handleSubmit = (e) => {
        e.preventDefault();
        const form = document.getElementById('addCampaignForm');
        if (form.checkValidity() === false) {
            e.preventDefault();
            e.stopPropagation();
            setValidated(true);
            return;
        }
        console.log(formData);
        dispatch(createCampaignThunk(formData));
    };

    const handleViewsChange = (views) => {
        console.log(views);
    };

    const handleClose = () => {
        setFormData({
            name: '',
            description: '',
            service: '',
            link_product: '',
            creator_type: '',
            creator_level: '',
            creator_count: 0,
            budget: [200, 600],
            creator_category: '',
            followers: [0, 100],
            gmv: '',
            views: [0, 100000],
            brand_id: brandId,
        });
        setValidated(false);
        onHide();
    };

    return (
        <Modal show={show} onHide={handleClose}>
            <Modal.Header>
                <Modal.Title>Add Campaign</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <Form id='addCampaignForm' noValidate validated={validated} onSubmit={handleSubmit}>
                    <Form.Group>
                        <Form.Label>Campaign Name *</Form.Label>
                        <Form.Control required type='text' name='name' value={formData.name} onChange={handleChange} />
                        <Form.Control.Feedback type='invalid'>Please enter campaign name.</Form.Control.Feedback>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Campaign Description *</Form.Label>
                        <Form.Control
                            required
                            type='text'
                            name='description'
                            isInvalid={!!errors.description}
                            value={formData.description}
                            onChange={handleChange}
                        />
                        <Form.Control.Feedback type='invalid'>Please enter campaign description.</Form.Control.Feedback>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Service *</Form.Label>
                        <Form.Select required name='service' value={formData.service} onChange={handleChange}>
                            <option value='' disabled>
                                Select Service
                            </option>
                            {CAMPAIGN_SERVICES.map((service) => (
                                <option key={service.value} value={service.value}>
                                    {service.name}
                                </option>
                            ))}
                        </Form.Select>
                        <Form.Control.Feedback type='invalid'>Please select a service.</Form.Control.Feedback>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Link Product *</Form.Label>
                        <Form.Control
                            type='text'
                            name='link_product'
                            value={formData.link_product}
                            onChange={handleChange}
                        />
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Creator Type *</Form.Label>
                        <Form.Select required name='creator_type' value={formData.creator_type} onChange={handleChange}>
                            <option value='' disabled>
                                Select Creator Type
                            </option>
                            {CREATOR_TYPES.map((creatorType) => (
                                <option key={creatorType.value} value={creatorType.value}>
                                    {creatorType.name}
                                </option>
                            ))}
                        </Form.Select>
                        <Form.Control.Feedback type='invalid'>Please select a creator type.</Form.Control.Feedback>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Creator Level *</Form.Label>
                        <Form.Select
                            required
                            name='creator_level'
                            value={formData.creator_level}
                            onChange={handleChange}
                        >
                            <option value='' disabled>
                                Select Creator Level
                            </option>
                            {CREATOR_LEVELS.map((creatorLevel) => (
                                <option key={creatorLevel.value} value={creatorLevel.value}>
                                    {creatorLevel.name}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label># Creators *</Form.Label>
                        <Form.Control
                            required
                            type='number'
                            name='creator_count'
                            value={formData.creator_count}
                            onChange={handleChange}
                        />
                        <Form.Control.Feedback type='invalid'>
                            Please enter the number of creators.
                        </Form.Control.Feedback>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Budget *</Form.Label>
                        <RangeSlider
                            discreteValues={budgetDiscreteValues}
                            value={formData.budget}
                            onChange={handleChange}
                        />
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Creator Category</Form.Label>
                        <Form.Select name='creator_category' value={formData.creator_category} onChange={handleChange}>
                            <option value=''>Select Creator Category</option>
                            {CREATOR_CATEGORIES.map((creatorCategory) => (
                                <option key={creatorCategory.value} value={creatorCategory.value}>
                                    {creatorCategory.name}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Followers</Form.Label>
                        <RangeSlider
                            discreteValues={followersDiscreteValues}
                            value={formData.followers}
                            onChange={handleChange}
                        />
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>GMV</Form.Label>
                        <Form.Select name='gmv' value={formData.gmv} onChange={handleChange}>
                            <option value=''>Select GMV</option>
                            {GMV_RANGES.map((gmv) => (
                                <option key={gmv.value} value={gmv.value}>
                                    {gmv.name}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Avg. Video Views</Form.Label>
                        <RangeSlider
                            discreteValues={viewsDiscreteValues}
                            value={formData.views}
                            onChange={handleViewsChange}
                        />
                    </Form.Group>
                </Form>
            </Modal.Body>
            <Modal.Footer>
                <Button variant='outline-primary' className='border-0' onClick={handleClose}>
                    Cancel
                </Button>
                <Button variant='primary' type='submit' form='addCampaignForm'>
                    Add Campaign
                </Button>
            </Modal.Footer>
        </Modal>
    );
}

export function AddProductModal({ show, onHide, brandId }) {
    const dispatch = useDispatch();
    const [productIds, setProductIds] = useState({
        0: '',
    });

    const addProduct = () => {
        const newIndex = Object.keys(productIds).length;
        console.log(newIndex);

        setProductIds((prev) => ({
            ...prev,
            [newIndex]: '',
        }));
    };

    const handleChange = (e) => {
        const { name, value } = e.target;
        setProductIds((prev) => ({
            ...prev,
            [name]: value,
        }));
    };

    const handleClose = () => {
        setProductIds([]);
        onHide();
    };

    const handleSubmit = (e) => {
        e.preventDefault();
        dispatch(
            setNotificationBarMessage({
                message: '这个接口是哪一个？',
                variant: 'info',
            })
        );
        const form = document.getElementById('addProductForm');
        if (form.checkValidity() === false) {
            e.preventDefault();
            e.stopPropagation();
            setValidated(true);
            return;
        }
        console.log(productIds);
    };

    const removeProduct = (index) => {
        if (Object.keys(productIds).length === 1) {
            return;
        }
        setProductIds((prev) => {
            const updated = { ...prev };
            delete updated[index];
            return updated;
        });
    };

    useEffect(() => {
        if (show) {
            setProductIds({
                0: '',
            });
        }
    }, [show]);

    return (
        <Modal show={show} onHide={handleClose}>
            <Modal.Header>
                <Modal.Title>Add Product</Modal.Title>
            </Modal.Header>
            <Form id='addProductForm' onSubmit={handleSubmit}>
                <Modal.Body>
                    {Object.entries(productIds).map(([index, productId]) => (
                        <Form.Group key={Number(index)}>
                            <Form.Label>Product {Number(index) + 1} PID</Form.Label>
                            <div className='d-flex flex-row align-items-center justify-content-between'>
                                <Form.Control
                                    type='text'
                                    name={index}
                                    value={productId}
                                    onChange={handleChange}
                                    placeholder='Enter Product ID'
                                    required
                                />
                                <Button variant='link' className='border-0' onClick={() => removeProduct(index)}>
                                    <X />
                                </Button>
                            </div>
                        </Form.Group>
                    ))}
                    <Button variant='outline-primary' className='mt-3' onClick={addProduct}>
                        Add Product
                    </Button>
                </Modal.Body>
                <Modal.Footer>
                    <Button variant='outline-primary' className='border-0' onClick={onHide}>
                        Cancel
                    </Button>
                    <Button variant='primary' type='submit'>
                        Submit
                    </Button>
                </Modal.Footer>
            </Form>
        </Modal>
    );
}
