import React, { useEffect, useState } from 'react';
import { Link, useParams } from 'react-router-dom';
import SearchBar from '../components/SearchBar';
import { Button, Col, Form, Modal, Row, Spinner, Table } from 'react-bootstrap';
import { useSelector, useDispatch } from 'react-redux';
import { fetchBrandDetail } from '../store/slices/brandsSlice';
import { fetchCampaignDetail, fetchMatchingResult, resetCurrentCampaign } from '../store/slices/campaignSlice';
import CampaignInfo from '../components/CampaignInfo';
import { ChevronRight, Send, Plus } from 'lucide-react';
import ProductsList from '../components/ProductsList';
import SlidePanel from '../components/SlidePanel';
import CampaignScript from './CampaignScript';
import { addProductToCampaign, fetchProducts, setCurrentProduct } from '../store/slices/productSlice';
import { determinProfileIcon } from '../lib/utils.jsx';

export default function CampaignDetail() {
    const { brandId, campaignId } = useParams();
    const dispatch = useDispatch();
    const { selectedBrand } = useSelector((state) => state.brands);
    const { currentCampaign } = useSelector((state) => state.campaign);
    const progressList = ['Find', 'Review', 'Confirmed', 'Draft Ready', 'Published'];
    const [progressIndex, setProgressIndex] = useState(2);
    const [activeTab, setActiveTab] = useState('products');
    const [showProductDetail, setShowProductDetail] = useState(false);
    const [showAddProductModal, setShowAddProductModal] = useState(false);
    const [additionalRequirements, setAdditionalRequirements] = useState({
        criteria: 'default',
        top_n: 10,
    });

    useEffect(() => {
        if (brandId && campaignId) {
            const fetchData = async () => {
                console.log(selectedBrand);
                if (!selectedBrand?.id) {
                    await dispatch(fetchBrandDetail(brandId)).unwrap();
                    dispatch(fetchCampaignDetail(campaignId));
                } else {
                    dispatch(fetchCampaignDetail(campaignId));
                }
                dispatch(fetchMatchingResult(additionalRequirements));
            };
            fetchData();
        }
        dispatch(fetchProducts());
    }, [dispatch, brandId, campaignId]);

    useEffect(() => {
        return () => {
            dispatch(resetCurrentCampaign());
        };
    }, []);

    const handleShowProductDetail = (product) => {
        dispatch(setCurrentProduct(product));
        setShowProductDetail(true);
    };

    const handleMatchCreators = async (e) => {
        e.preventDefault();
        await dispatch(fetchMatchingResult(additionalRequirements)).unwrap();
    };

    return (
        currentCampaign && (
            <div className='campaign-detail'>
                <div className='breadcrumb'>
                    <Link to={'/brands'} className='breadcrumb-item'>
                        Brands
                    </Link>
                    <Link to={`/brands/${brandId}`} className='breadcrumb-item'>
                        {selectedBrand?.name}
                    </Link>
                    <div className='breadcrumb-item'>{currentCampaign.name}</div>
                </div>
                <div className='function-bar'>
                    <SearchBar />
                    <Button>
                        <Send size={18} />
                        Email
                    </Button>
                </div>
                <CampaignInfo />
                <Form className='campaign-requirements shadow-xs' onSubmit={handleMatchCreators}>
                    <Form.Group className='mb-3 additional_requirements' controlId='additional_requirements'>
                        <Form.Label>Additional Requirements</Form.Label>
                        <Form.Control
                            type='text'
                            placeholder=''
                            value={additionalRequirements.criteria}
                            onChange={(e) =>
                                setAdditionalRequirements({ ...additionalRequirements, criteria: e.target.value })
                            }
                        />
                    </Form.Group>
                    <Form.Group className='mb-3 creator_requirements' controlId='creator_requirements'>
                        <Form.Label>Creators</Form.Label>
                        <Form.Control
                            type='number'
                            value={additionalRequirements.top_n}
                            onChange={(e) =>
                                setAdditionalRequirements({ ...additionalRequirements, top_n: e.target.value })
                            }
                        />
                    </Form.Group>
                    <Button type='submit' variant='primary-subtle'>
                        Match Creators
                    </Button>
                </Form>
                <div className='campaign-progress shadow-xs'>
                    {progressList.map((item, index) =>
                        index < progressList.length - 1 ? (
                            <React.Fragment key={index}>
                                <div
                                    className={`campaign-progress-item ${progressIndex === index ? 'active' : ''}`}
                                    key={index}
                                >
                                    <div className='campaign-progress-item-index'>{index + 1}</div>
                                    <div className='campaign-progress-item-label'>{item}</div>
                                    <div className='campaign-progress-item-desc'>xx Creators</div>
                                </div>
                                <ChevronRight />
                            </React.Fragment>
                        ) : (
                            <div
                                className={`campaign-progress-item ${progressIndex === index ? 'active' : ''}`}
                                key={index}
                            >
                                <div className='campaign-progress-item-index'>{index + 1}</div>
                                <div className='campaign-progress-item-label'>{item}</div>
                                <div className='campaign-progress-item-desc'>xx Creators</div>
                            </div>
                        )
                    )}
                </div>
                <div className='campaign-tab-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'products' ? 'active' : ''}`}
                        onClick={() => setActiveTab('products')}
                    >
                        Products
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'accepted_creators' ? 'active' : ''}`}
                        onClick={() => setActiveTab('accepted_creators')}
                    >
                        Accepted Creators
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'matching_result' ? 'active' : ''}`}
                        onClick={() => setActiveTab('matching_result')}
                    >
                        Matching Result
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'email_draft' ? 'active' : ''}`}
                        onClick={() => setActiveTab('email_draft')}
                    >
                        Email Draft
                    </div>
                </div>

                {activeTab === 'products' && (
                    <>
                        <Button
                            className='add-product-btn'
                            variant='outline-primary'
                            onClick={() => setShowAddProductModal(true)}
                        >
                            <Plus size={18} />
                            Add Product
                        </Button>
                        <ProductsList
                            products={currentCampaign?.link_product_details}
                            onShowProductDetail={handleShowProductDetail}
                        />
                        <SlidePanel
                            show={showProductDetail}
                            onClose={() => setShowProductDetail(false)}
                            title='Product Detail'
                            size='xxl'
                        >
                            <CampaignScript />
                        </SlidePanel>
                        <AddProductModal
                            campaignId={campaignId}
                            show={showAddProductModal}
                            onHide={() => setShowAddProductModal(false)}
                        />
                    </>
                )}
                {activeTab === 'accepted_creators' && <AcceptedCreators />}
                {activeTab === 'matching_result' && <MatchingResult />}
            </div>
        )
    );
}

function AddProductModal({ campaignId, show, onHide }) {
    const [selectedProduct, setSelectedProduct] = useState(null);
    const { products } = useSelector((state) => state.products);
    const dispatch = useDispatch();

    const handleCancel = () => {
        onHide();
        setSelectedProduct(null);
    };

    const handleSubmit = async () => {
        if (!selectedProduct) return;
        console.log(selectedProduct);
        await dispatch(addProductToCampaign({ campaignId, productId: selectedProduct })).unwrap();
        dispatch(fetchCampaignDetail(campaignId));
        handleCancel();
    };

    return (
        <Modal show={show} onHide={handleCancel} size='sm'>
            <Modal.Header closeButton className='fw-bold'>
                Add Product
            </Modal.Header>
            <Modal.Body>
                <Form className='add-product-form'>
                    <Form.Group className='mb-3'>
                        <Form.Label>Product PID</Form.Label>
                        <Form.Select
                            aria-label='Default select example'
                            value={selectedProduct}
                            onChange={(e) => setSelectedProduct(e.target.value)}
                        >
                            <option>Select</option>
                            {products?.length > 0 &&
                                products.map((product) => (
                                    <option key={product.id} value={product.id}>
                                        {product.name}
                                    </option>
                                ))}
                        </Form.Select>
                    </Form.Group>
                    <div className='button-group'>
                        <Button variant='outline-light' className='text-primary' onClick={handleCancel}>
                            Cancel
                        </Button>
                        <Button variant='primary' onClick={handleSubmit}>
                            Create
                        </Button>
                    </div>
                </Form>
            </Modal.Body>
        </Modal>
    );
}

function AcceptedCreators() {
    const { currentCampaign } = useSelector((state) => state.campaign);

    const handleSort = (field) => {
        return;
        console.log(field);
    };

    const renderSortIcon = (field) => {
        return;
        return <ChevronDown size={18} />;
    };

    const renderStatusPill = (status) => {
        switch (status) {
            case 'unconnected':
                return <span className='status-pill'>Unconnected</span>;
            case 'connected':
                return <span className='status-pill'>Connected</span>;
            case 'pending':
                return <span className='status-pill'>Pending</span>;
            case 'rejected':
                return <span className='status-pill'>Rejected</span>;
            case 'accepted':
                return <span className='status-pill'>Accepted</span>;
            case 'provided':
                return <span className='status-pill'>Provided</span>;
            case 'completed':
                return <span className='status-pill'>Completed</span>;
            case 'draft':
                return <span className='status-pill'>Draft</span>;
            case 'published':
                return <span className='status-pill'>Published</span>;
            default:
                return <span className='status-pill'>Unknown</span>;
        }
    };

    return (
        <div className='accepted-creators-table w-100'>
            <div className='table-container'>
                <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden'>
                    <thead className='sticky-header'>
                        <tr>
                            {/* <th className='selector' style={{ width: '40px' }}>
                                <Form.Check
                                    type='checkbox'
                                    checked={
                                        currentCampaign?.creators?.length === publicCreators.length && publicCreators.length > 0
                                    }
                                    onChange={handleSelectAll}
                                />
                            </th> */}
                            <th className='creator' onClick={() => handleSort('name')} style={{ width: '180px' }}>
                                Creator {renderSortIcon('name')}
                            </th>
                            <th
                                className='category text-center'
                                onClick={() => handleSort('category')}
                                style={{ width: '180px' }}
                            >
                                Category {renderSortIcon('category')}
                            </th>
                            <th className='followers text-center' onClick={() => handleSort('followers')}>
                                Followers {renderSortIcon('followers')}
                            </th>
                            <th className='gmv text-center' onClick={() => handleSort('gmv')}>
                                GMV {renderSortIcon('gmv')}
                            </th>
                            <th className='views text-center' onClick={() => handleSort('avg_video_views')}>
                                Avg. Video Views {renderSortIcon('avg_video_views')}
                            </th>
                            <th className='status text-center'>Status</th>
                            <th className='pricing text-center'>Pricing</th>
                            <th className='collaboration text-center'>Collaboration</th>
                            <th className='profile text-center'>Profile</th>
                        </tr>
                    </thead>
                    <tbody>
                        {!currentCampaign?.creators || currentCampaign?.creators?.length <= 0 ? (
                            <>
                                <tr>
                                    <td colSpan='9' className='text-center py-4'>
                                        No creators found.
                                    </td>
                                </tr>
                                <tr>
                                    <td colSpan={9}>
                                        <StepProgress />
                                    </td>
                                </tr>
                            </>
                        ) : (
                            currentCampaign?.creators?.map((creator) => (
                                <tr
                                    key={creator.creator_id}
                                    className={
                                        currentCampaign?.creators?.includes(creator.creator_id) ? 'selected' : ''
                                    }
                                >
                                    {/* <td>
                                        <Form.Check
                                            type='checkbox'
                                            checked={selectedCreators.includes(creator.creator_id)}
                                            onChange={() => handleSelectCreator(creator.creator_id)}
                                        />
                                    </td> */}
                                    <td className='creator-cell'>
                                        <div className='d-flex align-items-center'>
                                            <div className='creator-avatar'>
                                                <img src={creator.avatar} alt={creator.name} />
                                                {creator.status && <span className='verified-badge'></span>}
                                            </div>
                                            <Link to={`/creator/${creator.creator_id}`} className='creator-name'>
                                                {creator.name}
                                            </Link>
                                        </div>
                                    </td>
                                    <td>
                                        <span className={`category-pill ${getCategoryClassName(creator.category)}`}>
                                            {creator.category}
                                        </span>
                                    </td>
                                    <td className='text-nowrap text-center'>{creator.followers}</td>
                                    <td className='text-center'>
                                        <div>{creator.gmv}</div>
                                        <div className='small text-muted'>Items Sold: {creator.soldPercentage}</div>
                                    </td>
                                    <td className='text-nowrap text-center'>{creator.avg_video_views}</td>
                                    <td className='text-center'>
                                        <div className='status-pill'>{renderStatusPill(creator.status)}</div>
                                    </td>
                                    <td className='text-center'>{creator.pricing}</td>
                                    <td className='text-center'>{creator.collaboration}</td>
                                    <td className='text-center'>{creator.profile}</td>
                                    <td colSpan={8}>
                                        <StepProgress dates={creator.dates} />
                                    </td>
                                </tr>
                            ))
                        )}
                    </tbody>
                </Table>
            </div>
        </div>
    );
}

function StepProgress({ dates = [] }) {
    const labels = [
        'Brand Review',
        'Price Negotiation',
        'Creator Confirmation',
        'Draft Ready',
        'Draft Approved',
        'Published',
    ];
    const steps = [
        { label: 'Brand Review', date: '12/30/2020' },
        { label: 'Price Negotiation', date: '12/30/2020' },
        { label: 'Creator Confirmation', date: '12/30/2020' },
        { label: 'Draft Ready', date: '12/30/2020' },
        { label: 'Draft Approved', date: '12/30/2020' },
        { label: 'Published', date: '12/30/2020' },
    ];
    return (
        <div className='inline-step-progress'>
            <div className='inline-step'></div>
            {steps.map((step, index) => {
                const isCompleted = !!dates[index];
                return (
                    <div className='inline-step' key={index}>
                        <div className={`circle ${isCompleted ? 'completed' : 'pending'}`}>
                            {isCompleted ? '✔' : ''}1
                        </div>
                        {index !== steps.length - 1 && <div className='line' />}
                        <div className='label'>
                            <span className='label-text'>{step.label}</span>
                            <br />
                            <span className='label-date'>{step.date || 'N/A'}</span>
                        </div>
                    </div>
                );
            })}
        </div>
    );
}

function MatchingResult() {
    const { currentCampaign } = useSelector((state) => state.campaign);
    const [showMatchingResultModal, setShowMatchingResultModal] = useState(false);

    const mockData = [
        {
            operation: 'Operation 1',
            creator_find: 100,
            creator_accepted: 100,
            avg_creator_pricing: 100,
            date: '2020-01-01',
        },
    ];
    return (
        <div className='matching-result-table w-100'>
            <div className='table-container'>
                <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden'>
                    <thead className='sticky-header'>
                        <tr>
                            <th># Operation</th>
                            <th># Creator Find</th>
                            <th># Creator Accepted</th>
                            <th>Avg. Creator Pricing</th>
                            <th>Date</th>
                            <th>View Details</th>
                        </tr>
                    </thead>
                    <tbody>
                        {mockData.length > 0 ? (
                            mockData.map((item, index) => (
                                <tr key={index}>
                                    <td>{item.operation}</td>
                                    <td>{item.creator_find}</td>
                                    <td>{item.creator_accepted}</td>
                                    <td>{item.avg_creator_pricing}</td>
                                    <td>{item.date}</td>
                                    <td>
                                        <Button
                                            variant='outline-primary'
                                            className='border-0'
                                            onClick={() => setShowMatchingResultModal(true)}
                                        >
                                            View
                                        </Button>
                                    </td>
                                </tr>
                            ))
                        ) : (
                            <tr>
                                <td colSpan={6} className='text-center'>
                                    No data
                                </td>
                            </tr>
                        )}
                    </tbody>
                </Table>
                <CampaignMatchingResult
                    show={showMatchingResultModal}
                    onHide={() => setShowMatchingResultModal(false)}
                />
            </div>
        </div>
    );
}

function CampaignMatchingResult({ show, onHide }) {
    const { currentCampaign } = useSelector((state) => state.campaign);

    return (
        <Modal show={show} onHide={onHide} size='lg'>
            <Modal.Header closeButton className='fw-bold'>
                Campaign Matching Result
            </Modal.Header>
            <Modal.Body>
                <div className='matching-result-table'>
                    <div className='table-container'>
                        <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden'>
                            <thead className='sticky-header'>
                                <tr>
                                    <th>Creator</th>
                                    <th>Category</th>
                                    <th>Followers</th>
                                    <th>GMV</th>
                                    <th>Avg. Video Views</th>
                                    <th>Status</th>
                                    <th>Pricing</th>
                                    <th>Profile</th>
                                </tr>
                            </thead>
                            <tbody>
                                {currentCampaign?.matching_result?.length > 0 ? (
                                    currentCampaign?.matching_result?.map((item, index) => (
                                        <tr key={index}>
                                            <td>{item.name}</td>
                                            <td>{item.category}</td>
                                            <td>{item.followers}</td>
                                            <td>{item.gmv}</td>
                                            <td>{item.avg_video_views}</td>
                                            <td>{item.status || '--'}</td>
                                            <td>{item.pricing}</td>
                                            <td>{determinProfileIcon(item)}</td>
                                        </tr>
                                    ))
                                ) : (
                                    <tr>
                                        <td colSpan={8} className='text-center'>
                                            No data
                                        </td>
                                    </tr>
                                )}
                            </tbody>
                        </Table>
                    </div>
                </div>
            </Modal.Body>
        </Modal>
    );
}
