import { createSlice, createAsyncThunk } from '@reduxjs/toolkit';
import api from '@/services/api';
import { setNotificationBarMessage } from './notificationBarSlice';

export const fetchProducts = createAsyncThunk('products/fetchProducts', async (_, { rejectWithValue, dispatch }) => {
    try {
        const response = await api.get('/products/');
        if (response.code !== 200) {
            throw new Error(response.message);
        }
        return response.data;
    } catch (error) {
        return rejectWithValue(error.message);
    }
});

export const addProductToCampaign = createAsyncThunk(
    'products/addProductToCampaign',
    async (formData, { rejectWithValue, dispatch }) => {
        try {
            const { campaignId, productId } = formData;
            const response = await api.post(`/campaigns/${campaignId}/add_product/`, { product_id: productId });
            if (response.code !== 201 && response.code !== 200) {
                throw new Error(response.message);
            }
            dispatch(setNotificationBarMessage({ message: response.message, type: 'success' }));
            return response.data;
        } catch (error) {
            dispatch(setNotificationBarMessage({ message: error.message, type: 'error' }));
            return rejectWithValue(error.message);
        }
    }
);

export const fetchProductDetail = createAsyncThunk(
    'products/fetchProductDetail',
    async (productId, { rejectWithValue, dispatch }) => {
        try {
            const response = await api.get(`/products/${productId}/`);
            if (response.code !== 200) {
                throw new Error(response.message);
            }
            return response.data;
        } catch (error) {
            dispatch(setNotificationBarMessage({ message: error.message, type: 'error' }));
            return rejectWithValue(error.message);
        }
    }
);

export const fetchProductCampaigns = createAsyncThunk('products/fetchProductCampaigns', async (productId, { rejectWithValue, dispatch }) => {
    try {
        const response = await api.get('/campaigns/by-product/', { params: { product_id: productId } });
        if (response.code !== 200) {
            throw new Error(response.message);
        }
        if (response.data.campaigns.length > 0) {
            response.data.campaigns.forEach((campaign) => {
                dispatch(fetchCampaignCreators(campaign.id));
            });
        }
        return response.data;
    } catch (error) {
        return rejectWithValue(error.message);
    }
});


export const fetchCampaignCreators = createAsyncThunk('products/fetchCampaignCreators', async (campaignId, { rejectWithValue }) => {
	try {
			const response = await api.get(`/campaigns/${campaignId}/creator_list/`);
			if (response.code !== 200) {
					throw new Error(response.message);
			}
			return { campaignId, creators: response.data.creators };
	} catch (error) {
			return rejectWithValue(error.message);
	}
});


const initialState = {
    products: [],
    status: 'idle', // idle, loading, success, error
    error: null,
    productDetail: null,
    currentProduct: null,
};

const productSlice = createSlice({
    name: 'products',
    initialState,
    reducers: {
        setCurrentProduct: (state, action) => {
            state.currentProduct = action.payload;
        },
    },
    extraReducers: (builder) => {
        builder.addCase(fetchProducts.pending, (state) => {
            state.status = 'loading';
        });
        builder.addCase(fetchProducts.fulfilled, (state, action) => {
            state.products = action.payload;
            state.status = 'success';
        });
        builder.addCase(fetchProducts.rejected, (state, action) => {
            state.error = action.payload;
            state.status = 'error';
        });
        builder.addCase(addProductToCampaign.pending, (state) => {
            state.status = 'loading';
        });
        builder.addCase(addProductToCampaign.fulfilled, (state, action) => {
            state.products = action.payload;
            state.status = 'success';
        });
        builder.addCase(addProductToCampaign.rejected, (state, action) => {
            state.error = action.payload;
            state.status = 'error';
        });
        builder.addCase(fetchProductDetail.pending, (state) => {
            state.status = 'loading';
        });
        builder.addCase(fetchProductDetail.fulfilled, (state, action) => {
            state.productDetail = action.payload;
            state.status = 'success';
        });
        builder.addCase(fetchProductDetail.rejected, (state, action) => {
            state.error = action.payload;
            state.status = 'error';
        });
        builder.addCase(fetchProductCampaigns.pending, (state) => {
            state.status = 'loading';
        });
        builder.addCase(fetchProductCampaigns.fulfilled, (state, action) => {
            state.currentProduct.campaigns = action.payload.campaigns || [];
            state.status = 'success';
        });
        builder.addCase(fetchProductCampaigns.rejected, (state, action) => {
            state.error = action.payload;
            state.status = 'error';
        });
        builder.addCase(fetchCampaignCreators.pending, (state) => {
            state.status = 'loading';
        });
        builder.addCase(fetchCampaignCreators.fulfilled, (state, action) => {
            state.currentProduct.campaigns.find((campaign) => campaign.id === action.payload.campaignId).creators = action.payload.creators;
            state.status = 'success';
        });
        builder.addCase(fetchCampaignCreators.rejected, (state, action) => {
            state.error = action.payload;
            state.status = 'error';
        });
    },
});

export const { setCurrentProduct } = productSlice.actions;

export default productSlice.reducer;
